@@ -254,6 +254,7 @@ class Token:
         isCast
         externLang
         isExpandedMacro    Is this token a expanded macro token
+        macroName          Macro name that this token is expanded from
         isRemovedVoidParameter  Has void parameter been removed?
         isSplittedVarDeclComma  Is this a comma changed to semicolon in a split variable declaration ('int a,b;' => 'int a; int b;')
         isSplittedVarDeclEq     Is this a '=' changed to semicolon in a split variable declaration ('int a=5;' => 'int a; a=5;')
@@ -313,6 +314,7 @@ class Token:
     isCast = False
     isUnsigned = False
     isSigned = False
+    macroName = None
     isExpandedMacro = False
     isRemovedVoidParameter = False
     isSplittedVarDeclComma = False
@@ -334,6 +336,7 @@ class Token:
 
     typeScopeId = None
     typeScope = None
+    type = None
 
     astParentId = None
     astParent = None
@@ -353,27 +356,27 @@ class Token:
         self.previous = None
         self.scopeId = element.get('scope')
         self.scope = None
-        type = element.get('type')
-        if type == 'name':
+        self.type = element.get('type')
+        if self.type == 'name':
             self.isName = True
             if element.get('isUnsigned'):
                 self.isUnsigned = True
             if element.get('isSigned'):
                 self.isSigned = True
-        elif type == 'number':
+        elif self.type == 'number':
             self.isNumber = True
             if element.get('isInt'):
                 self.isInt = True
             elif element.get('isFloat'):
                 self.isFloat = True
-        elif type == 'string':
+        elif self.type == 'string':
             self.isString = True
             self.strlen = int(element.get('strlen'))
-        elif type == 'char':
+        elif self.type == 'char':
             self.isChar = True
-        elif type == 'boolean':
+        elif self.type == 'boolean':
             self.isBoolean = True
-        elif type == 'op':
+        elif self.type == 'op':
             self.isOp = True
             if element.get('isArithmeticalOp'):
                 self.isArithmeticalOp = True
@@ -386,7 +389,8 @@ class Token:
         if element.get('isCast'):
             self.isCast = True
         self.externLang = element.get('externLang')
-        if element.get('isExpandedMacro'):
+        self.macroName = element.get('macroName')
+        if self.macroName or element.get('isExpandedMacro'):
             self.isExpandedMacro = True
         if element.get('isRemovedVoidParameter'):
             self.isRemovedVoidParameter = True
@@ -566,6 +570,7 @@ class Scope:
     function = None
     nestedInId = None
     nestedIn = None
+    nestedList = None
     type = None
     isExecutable = None
     varlistId = None
@@ -583,6 +588,7 @@ class Scope:
         self.bodyEnd = None
         self.nestedInId = element.get('nestedIn')
         self.nestedIn = None
+        self.nestedList = list()
         self.type = element.get('type')
         self.definedType = element.get('definedType')
         self.isExecutable = (self.type in ('Function', 'If', 'Else', 'For', 'While', 'Do',
@@ -603,6 +609,8 @@ class Scope:
         self.bodyStart = IdMap[self.bodyStartId]
         self.bodyEnd = IdMap[self.bodyEndId]
         self.nestedIn = IdMap[self.nestedInId]
+        if self.nestedIn:
+            self.nestedIn.nestedList.append(self)
         self.function = IdMap[self.functionId]
         for v in self.varlistId:
             value = IdMap.get(v)
@@ -823,7 +831,7 @@ class Value:
         intvalue         integer value
         tokvalue         token value
         floatvalue       float value
-        movedValue
+        movedvalue
         uninit
         containerSize    container size
         bufferSize       buffer size
@@ -893,7 +901,7 @@ class Value:
         self.symbolic = IdMap.get(self._symbolicId)
 
     def __repr__(self):
-        attrs = ["intvalue", "tokvalue", "floatvalue", "movedValue", "uninit", 
+        attrs = ["intvalue", "tokvalue", "floatvalue", "movedvalue", "uninit", 
                  "bufferSize", "containerSize", "condition", "valueKind"]
         return "{}({})".format(
             "Value",
@@ -938,29 +946,60 @@ class Suppression:
       fileName    The name of the file to suppress warnings for, can include wildcards
       lineNumber  The number of the line to suppress warnings from, can be 0 to represent any line
       symbolName  The name of the symbol to match warnings for, can include wildcards
+      lineBegin   The first line to suppress warnings from
+      lineEnd     The last line to suppress warnings from
+      suppressionType   The type of suppression which is applied (unique = None (default), file, block, blockBegin, blockEnd, macro)
     """
 
     errorId = None
     fileName = None
     lineNumber = None
     symbolName = None
+    lineBegin = None
+    lineEnd = None
+    suppressionType = None
 
     def __init__(self, element):
         self.errorId = element.get('errorId')
         self.fileName = element.get('fileName')
         self.lineNumber = element.get('lineNumber')
         self.symbolName = element.get('symbolName')
+        self.lineBegin = element.get('lineBegin')
+        self.lineEnd = element.get('lineEnd')
+        self.suppressionType = element.get('type')
 
     def __repr__(self):
-        attrs = ['errorId' , "fileName", "lineNumber", "symbolName"]
+        attrs = ["errorId", "fileName", "lineNumber", "symbolName", "lineBegin", "lineEnd","suppressionType"]
         return "{}({})".format(
             "Suppression",
             ", ".join(("{}={}".format(a, repr(getattr(self, a))) for a in attrs))
         )
 
     def isMatch(self, file, line, message, errorId):
+        # Line Suppression
         if ((self.fileName is None or fnmatch(file, self.fileName))
-                and (self.lineNumber is None or int(line) == int(self.lineNumber))
+                and (self.suppressionType == None) # Verify use of default suppression type (None = unique)
+                and (self.lineNumber != None and int(line) == int(self.lineNumber))
+                and (self.symbolName is None or fnmatch(message, '*'+self.symbolName+'*'))
+                and fnmatch(errorId, self.errorId)):
+            return True
+        # File Suppression
+        if ((self.fileName is None or fnmatch(file, self.fileName))
+                and (self.suppressionType != None and self.suppressionType == "file") # Verify use of file (global) suppression type
+                and (self.symbolName is None or fnmatch(message, '*'+self.symbolName+'*'))
+                and fnmatch(errorId, self.errorId)):
+            return True
+        # Block Suppression Mode
+        if ((self.fileName is None or fnmatch(file, self.fileName))
+                and (self.suppressionType != None and self.suppressionType == "block") # Type for Block suppression
+                and (self.lineBegin != None and int(line) > int(self.lineBegin)) # Code Match is between the Block suppression
+                and (self.lineEnd != None and int(line) < int(self.lineEnd)) # Code Match is between the Block suppression
+                and (self.symbolName is None or fnmatch(message, '*'+self.symbolName+'*'))
+                and fnmatch(errorId, self.errorId)):
+            return True
+        # Other Suppression (Globaly set via suppression file or cli command)
+        if ((self.fileName is None or fnmatch(file, self.fileName))
+                and (self.suppressionType is None) 
                 and (self.symbolName is None or fnmatch(message, '*'+self.symbolName+'*'))
                 and fnmatch(errorId, self.errorId)):
             return True
@@ -1612,11 +1651,19 @@ def is_suppressed(location, message, errorId):
             return True
     return False
 
-def reportError(location, severity, message, addon, errorId, extra=''):
+def log_checker(message, addon):
+    if '--cli' in sys.argv:
+        msg = { 'addon': addon,
+                'severity': 'none',
+                'message': message,
+                'errorId': 'logChecker'}
+        sys.stdout.write(json.dumps(msg) + '\n')
+
+def reportError(location, severity, message, addon, errorId, extra='', columnOverride=None):
     if '--cli' in sys.argv:
         msg = { 'file': location.file,
                 'linenr': location.linenr,
-                'column': location.column,
+                'column': location.column if columnOverride is None else columnOverride,
                 'severity': severity,
                 'message': message,
                 'addon': addon,
